@@ -94,12 +94,15 @@ class UserIdExtract(BaseObject):
                     if 'elements' in block:
                         for element in block['elements']:
 
-                            if 'elements' not in element:
-                                continue
+                            if 'elements' not in element and 'text' in element:
+                                tokens = element['text'].split()
+                                if tokens[0].startswith('<@'):
+                                    user_ids.append(tokens[0][2:-1])
 
-                            for inner in element['elements']:
-                                if inner['type'] == 'user':
-                                    if inner['user_id'] not in user_ids:
+                            else:
+
+                                for inner in element['elements']:
+                                    if inner['type'] == 'user' and inner['user_id'] not in user_ids:
                                         user_ids.append(inner['user_id'])
 
                     elif 'text' in block:  # slackbot-helper/issues/1
